Bumps the package version in mix.exs.
Usage:
mix nebula_graph_ex.version patch
mix nebula_graph_ex.version minor
mix nebula_graph_ex.version majorIf no bump type is provided, the task prompts interactively.
Bumps the package version in mix.exs.
Usage:
mix nebula_graph_ex.version patch
mix nebula_graph_ex.version minor
mix nebula_graph_ex.version majorIf no bump type is provided, the task prompts interactively.