NebulaGraphEx.Error.Code (nebula_graph_ex v0.1.8)

Copy Markdown View Source

Mapping between NebulaGraph integer error codes and Elixir atoms.

See priv/thrift/common.thrift ErrorCode enum for the full list.

Summary

Functions

Converts a raw integer error code to an atom. Returns :e_unknown for unrecognised codes.

Returns true if the code represents a successful operation.

Functions

from_int(int)

@spec from_int(integer()) :: atom()

Converts a raw integer error code to an atom. Returns :e_unknown for unrecognised codes.

succeeded?(arg1)

@spec succeeded?(atom() | integer()) :: boolean()

Returns true if the code represents a successful operation.