NebulaGraphEx.Types.Tag (nebula_graph_ex v0.1.10)

Copy Markdown View Source

A tag (label) attached to a NebulaGraphEx.Types.Vertex, carrying a map of property names to decoded Elixir values.

Fields

  • :name — tag name binary, e.g. "Player".
  • :props — map of binary() => term() property values.

Example

%NebulaGraphEx.Types.Tag{
  name: "Player",
  props: %{"name" => "Tim Duncan", "age" => 42}
}

Summary

Functions

Returns the value of a property by name, or nil.

Types

t()

@type t() :: %NebulaGraphEx.Types.Tag{
  name: String.t(),
  props: %{required(String.t()) => term()}
}

Functions

get(tag, key)

@spec get(t(), String.t()) :: term()

Returns the value of a property by name, or nil.