Mapping between NebulaGraph integer error codes and Elixir atoms.
See priv/thrift/common.thrift ErrorCode enum for the full list.
Summary
Functions
Converts a raw integer error code to an atom. Returns :e_unknown for unrecognised codes.
Returns true if the code represents a successful operation.