NebulaGraph duration value.
Durations are stored as a combination of months, seconds, and microseconds because months cannot be represented as a fixed number of seconds (they vary in length).
Fields
:months— total months component:seconds— seconds component (independent of months):microseconds— sub-second component
Summary
Functions
Returns the total number of seconds in the non-month component.
Does not account for the :months field (months are calendar-dependent).